summaryrefslogtreecommitdiffstats
path: root/src/usr/local/www/js
diff options
context:
space:
mode:
authorStephen Beaver <sbeaver@netgate.com>2016-04-11 08:39:33 -0400
committerStephen Beaver <sbeaver@netgate.com>2016-04-11 11:39:19 -0400
commit359b630c8beee000b84d4067f6bbf3c5ba5f225c (patch)
tree93e7d7b6a5418c801fd46031f8ee01880f0231ec /src/usr/local/www/js
parentd41132b19901d52c847269619cd3c8f2a0e91f01 (diff)
downloadpfsense-359b630c8beee000b84d4067f6bbf3c5ba5f225c.zip
pfsense-359b630c8beee000b84d4067f6bbf3c5ba5f225c.tar.gz
Merged #2854 and updated to increment only the deleterow button
Diffstat (limited to 'src/usr/local/www/js')
-rw-r--r--src/usr/local/www/js/pfSenseHelpers.js4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/usr/local/www/js/pfSenseHelpers.js b/src/usr/local/www/js/pfSenseHelpers.js
index 9b3d884..61453d5 100644
--- a/src/usr/local/www/js/pfSenseHelpers.js
+++ b/src/usr/local/www/js/pfSenseHelpers.js
@@ -313,8 +313,8 @@ function add_row() {
$(this).val('');
});
- // Increment the suffix number for each button element in the new group
- $(newGroup).find('button').each(function() {
+ // Increment the suffix number for the deleterow button element in the new group
+ $(newGroup).find('[id^=deleterow]').each(function() {
$(this).prop("id", bumpStringInt(this.id));
$(this).prop("name", bumpStringInt(this.name));
});
OpenPOWER on IntegriCloud